<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<!--
		Function name: DrawDiskDetailsDiv
		In Element	 : disk
	  	Description  : Draw disk details table in a hidden div; 
	-->
	<xsl:template name="DrawDiskDetailsDiv">
		<xsl:variable name="infobgcolor">#FFFFCC</xsl:variable>
		<!--Draw disk information div-->
		<DIV style="Z-INDEX: 1; VISIBILITY: hidden; POSITION: absolute" id="DetailDiv_{@id}">
			<table border="1" bgcolor="{$infobgcolor}">
				<tbody>
					<tr>
						<td>Model</td>
						<td>
							<xsl:value-of select="model"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Type</td>
						<td>
							<xsl:value-of select="type"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Location</td>
						<td>
							<xsl:value-of select="location"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Revision</td>
						<td>
							<xsl:value-of select="revision"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Capacity</td>
						<td>
							<xsl:value-of select="capacity"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Max Free</td>
						<td>
							<xsl:value-of select="max_free"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Total Free</td>
						<td>
							<xsl:value-of select="total_free"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Status</td>
						<td>
							<xsl:value-of select="flags/@des"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Transfer Mode</td>
						<td>
							<xsl:value-of select="mode"></xsl:value-of>
						</td>
					</tr>
				</tbody>
			</table>
		</DIV>
	</xsl:template>
	<!--
		Function name: DrawArrayDetailsDiv
		In Element	 : array
	  	Description  : Draw array hint table; 
	-->
	<xsl:template name="DrawArrayDetailDiv">
		<xsl:variable name="infobgcolor">#FFFFCC</xsl:variable>
		<!--Draw Array information div-->
		<DIV style="Z-INDEX: 1; VISIBILITY: hidden; POSITION: absolute" id="DetailDiv_{@id}">
			<table border="1" bgcolor="{$infobgcolor}">
				<tbody>
					<tr>
						<td>Name</td>
						<td>
							<xsl:value-of select="name"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Type</td>
						<td>
							<xsl:value-of select="type"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Status</td>
						<td>
							<xsl:value-of select="flags/@des"></xsl:value-of>
						</td>
					</tr>
					<tr>
						<td>Capacity</td>
						<td>
							<xsl:value-of select="capacity"></xsl:value-of>
						</td>
					</tr>
					<xsl:if test="count(block_size)!=0">
						<tr>
							<td>Block Size</td>
							<td>
								<xsl:value-of select="block_size"></xsl:value-of>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="count(build_progress)!=0">
						<tr>
							<td>Progress</td>
							<td>
								<xsl:value-of select="build_progress"></xsl:value-of>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="count(trans_progress)!=0">
						<tr>
							<td>Transform Progress</td>
							<td>
								<xsl:value-of select="trans_progress"></xsl:value-of>
							</td>
						</tr>
					</xsl:if>
					<xsl:if test="count(cache_policy)!=0">
						<tr>
							<td>Cache Policy</td>
							<td>
								<xsl:value-of select="cache_policy"></xsl:value-of>
							</td>
						</tr>
					</xsl:if>
				</tbody>
			</table>
		</DIV>
		<xsl:for-each select="members/array">
			<xsl:call-template name="DrawArrayDetailDiv"/>
		</xsl:for-each>
		<xsl:for-each select="target">
			<xsl:call-template name="DrawArrayDetailDiv"/>
		</xsl:for-each>
	</xsl:template>
	<!--
		Function name: DrawDevImgTable
		In Element	 : array,disk
		Parameter	 : enablehint, enable hint shown; preimgid, image id(preimgid_diskid),
	  	Description  : Draw disk or array image table; Type image as background, flag image as ite foreground.
	-->
	<xsl:variable name="cellsize">24</xsl:variable>
	<xsl:variable name="cellsize2">11</xsl:variable>
	<!--xsl:variable name="cellsize2">
		<xsl:value-of select="$cellsize div 2"/>
	</xsl:variable-->
	<xsl:template name="DrawDevImgTable">
		<xsl:param name="preimgid">imgtable</xsl:param>
		<xsl:param name="enablehint">false</xsl:param>
		<table border="0" width="{$cellsize}" height="{$cellsize}" cellspacing="0" cellpadding="0" background="{type/@id}.gif">
			<xsl:if test="($enablehint='true')and(@id!='arr_0')and(@id!='disk_0')">
				<xsl:attribute name="id">
					<xsl:value-of select="$preimgid"/>_<xsl:value-of select="@id"/></xsl:attribute>
				<xsl:attribute name="onmouseover">ShowHint('<xsl:value-of select="@id"/>','<xsl:value-of select="$preimgid"/>_<xsl:value-of select="@id"/>');return;</xsl:attribute>
				<xsl:attribute name="onmouseout">HideHint();return;</xsl:attribute>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="count(flags/flag)=0">
					<tr>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
					</tr>
					<tr>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
					</tr>
				</xsl:when>
				<xsl:when test="count(flags/flag)=1">
					<tr>
						<td width="{$cellsize2}" height="{$cellsize2}">
							<img src="{flags/flag/@id}.gif" width="{$cellsize2}" height="{$cellsize2}"/>
						</td>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
					</tr>
					<tr>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
					</tr>
				</xsl:when>
				<xsl:when test="count(flags/flag)=2">
					<tr>
						<xsl:for-each select="flags/flag">
							<td width="{$cellsize2}" height="{$cellsize2}">
								<img src="{@id}.gif" width="{$cellsize2}" height="{$cellsize2}"/>
							</td>
						</xsl:for-each>
					</tr>
					<tr>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
					</tr>
				</xsl:when>
				<xsl:when test="count(flags/flag)=3">
					<tr>
						<xsl:for-each select="flags/flag">
							<xsl:if test="position()&lt;3">
								<td width="{$cellsize2}" height="{$cellsize2}">
									<img src="{@id}.gif" width="{$cellsize2}" height="{$cellsize2}"/>
								</td>
							</xsl:if>
						</xsl:for-each>
					</tr>
					<tr>
						<xsl:for-each select="flags/flag">
							<xsl:if test="position()&gt;2">
								<td width="{$cellsize2}" height="{$cellsize2}">
									<img src="{@id}.gif" width="{$cellsize2}" height="{$cellsize2}"/>
								</td>
							</xsl:if>
						</xsl:for-each>
						<td width="{$cellsize2}" height="{$cellsize2}"></td>
					</tr>
				</xsl:when>
				<xsl:when test="count(flags/flag)=4">
					<tr>
						<xsl:for-each select="flags/flag">
							<xsl:if test="position()&lt;3">
								<td width="{$cellsize2}" height="{$cellsize2}">
									<img src="{@id}.gif" width="{$cellsize2}" height="{$cellsize2}"/>
								</td>
							</xsl:if>
						</xsl:for-each>
					</tr>
					<tr>
						<xsl:for-each select="flags/flag">
							<xsl:if test="position()&gt;2">
								<td width="{$cellsize2}" height="{$cellsize2}">
									<img src="{@id}.gif" width="{$cellsize2}" height="{$cellsize2}"/>
								</td>
							</xsl:if>
						</xsl:for-each>
					</tr>
				</xsl:when>
			</xsl:choose>
		</table>
	</xsl:template>

	<!--
		Function name: DrawDevRefTable
		In Element	 : dev_ref
	  	Description  : Draw simple array or disk information table.
	-->
	<xsl:template name="DrawDevRefTable">
		<xsl:param name="width">100%</xsl:param>
		<table border="0" width="{$width}" cellspacing="0" cellpadding="0" height="20">
			<tr>
				<xsl:call-template name="DrawDevInfoRowCell">
					<xsl:with-param name="simple">true</xsl:with-param>
				</xsl:call-template>
			</tr>
		</table>
	</xsl:template>
	<!--
		Function name: DrawArrayTreeTable
		In Element	 : array
	  	Description  : Draw array tree. It will be recusive call if array has a array member.
	-->
	<xsl:template name="DrawArrayTreeTable">
		<table border="0" width="100%" cellspacing="0" cellpadding="0">
			<!--First row-->
			<tr>
				<td width="{$cellsize}" height="{$cellsize}">
					<xsl:call-template name="DrawDevImgTable">
						<xsl:with-param name="enablehint">false</xsl:with-param>
						<xsl:with-param name="preimgid">AT</xsl:with-param>
					</xsl:call-template>
				</td>
				<td>
					<font class="devattribute">
						<xsl:value-of select="name"/>
					</font>
				</td>
			</tr>
			<xsl:for-each select="members/array">
				<xsl:variable name="memcount">
					<xsl:value-of select="count(members/dev_ref)"/>
				</xsl:variable>
				<xsl:variable name="memsize">
					<xsl:value-of select="$cellsize*$memcount"/>
				</xsl:variable>
				<!--Second row-->
				<xsl:if test="not(position()=last())">
					<tr>
						<td>
							<img src="linemid24.gif" width="{$cellsize}" height="{$cellsize}" border="0"/>
						</td>
						<td rowspan="2">
							<xsl:call-template name="DrawArrayTreeTable"/>
						</td>
					</tr>
					<tr>
						<td width="{$cellsize}" height="{$memsize}" background="line24.gif"></td>
					</tr>
				</xsl:if>
				<xsl:if test="position()=last()">
					<tr>
						<td>
							<img src="linetail24.gif" width="{$cellsize}" height="{$cellsize}" border="0"/>
						</td>
						<td rowspan="2">
							<xsl:call-template name="DrawArrayTreeTable"/>
						</td>
					</tr>
					<tr>
						<td width="{$cellsize}" height="{$memsize}"></td>
					</tr>
				</xsl:if>
			</xsl:for-each>
			<xsl:for-each select="members/dev_ref">
				<!--Second row-->
				<tr>
					<xsl:if test="not(position()=last())">
						<!--td height="20"><img src="linemid24.gif" width="{$cellsize}" height="{$cellsize}" border="0"/></td-->
						<td height="{$cellsize}" width="{$cellsize}" background="linemid24.gif"/>
					</xsl:if>
					<xsl:if test="position()=last()">
						<!--td  height="20" rowspan="2"><img src="linetail24.gif" width="{$cellsize}" height="{$cellsize}" border="0"/></td-->
						<td height="{$cellsize}" width="{$cellsize}" background="linetail24.gif"/>
					</xsl:if>
					<td  height="{$cellsize}"><xsl:call-template name="DrawDevRefTable"/></td>
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template>
	<!--
		Function name: DrawDevInfoRowCell
		In Element	 : array,disk,dev_ref
	  	Description  : Draw a table row describe array's or disk's information.
					   Simple must equal true when dev_ref passed in.
	-->
	<xsl:template name="DrawDevInfoRowCell">
		<xsl:param name="simple">false</xsl:param>
		<xsl:param name="enablehint">false</xsl:param>
		<!--Picture-->
		<td width="{$cellsize}">
			<xsl:call-template name="DrawDevImgTable">
				<xsl:with-param name="preimgid">DevR</xsl:with-param>
				<xsl:with-param name="enablehint">
					<xsl:value-of select="$enablehint"/>
				</xsl:with-param>
			</xsl:call-template>
		</td>
		<!--Name-->
		<td>
			<font class="devattribute">
				<xsl:value-of select="name"/>
			</font>
		</td>
		<xsl:if test="$simple='false'">
			<td>
				<font class="devattribute">
					<xsl:value-of select="type"/>
				</font>
			</td>
			<td>
				<font class="devattribute">
					<xsl:value-of select="capacity"/>
				</font>
			</td>
			<td>
				<font class="devattribute">
					<xsl:value-of select="osname"/>
				</font>
			</td>
			<td>
				<font class="devattribute">
					<xsl:value-of select="flags/@des"/>
				</font>
			</td>
		</xsl:if>
	</xsl:template>

	<!--
		Function name: DrawArrayInfoRowCell
		In Element	 : array
	  	Description  : Draw a table row describe array's information.
	-->
	<xsl:template name="DrawArrayInfoRowCell">
		<xsl:param name="enablehint">false</xsl:param>
		<!--Picture-->
		<td width="{$cellsize}">
			<xsl:call-template name="DrawDevImgTable">
				<xsl:with-param name="preimgid">DevR</xsl:with-param>
				<xsl:with-param name="enablehint">
					<xsl:value-of select="$enablehint"/>
				</xsl:with-param>
			</xsl:call-template>
		</td>
		<td>
			<font class="devattribute">
				<xsl:value-of select="name"/>
			</font>
		</td>
		<td>
			<font class="devattribute">
				<xsl:value-of select="type"/>
			</font>
		</td>
		<td>
			<font class="devattribute">
				<xsl:value-of select="capacity"/>
			</font>
		</td>
		<td>
			<font class="devattribute">
				<xsl:value-of select="cache_policy"/>
			</font>
		</td>

		<td>
			<font class="devattribute">
				<xsl:value-of select="osname"/>
			</font>
		</td>
		<td>
			<font class="devattribute">
				<xsl:value-of select="flags/@des"/>
			</font>
		</td>
	</xsl:template>

	<xsl:template name="DrawDiskInfoRowCell">
		<xsl:param name="simple">false</xsl:param>
		<!--Picture-->
		<td width="{$cellsize}">
			<xsl:call-template name="DrawDevImgTable">
				<xsl:with-param name="preimgid">DiskR</xsl:with-param>
			</xsl:call-template>
		</td>
		<!--Name-->
		<td>
			<font class="devattribute">
				<xsl:value-of select="location"/>
			</font>
		</td>
		<td>
			<font class="devattribute">
				<xsl:value-of select="model"/>
			</font>
		</td>
		
		<td>
			<font class="devattribute">
				<xsl:value-of select="capacity"/>
			</font>
		</td>
		<td>
			<font class="devattribute">
				<xsl:value-of select="max_free"/>
			</font>
		</td>
		<xsl:if test="$simple='false'">
			<!--td>
				<font class="devattribute">
					<xsl:value-of select="location"/>
				</font>
			</td-->
			<td>
				<font class="devattribute">
					<xsl:value-of select="total_free"/>
				</font>
			</td>
			<td>
				<font class="devattribute">
					<xsl:value-of select="mode"/>
				</font>
			</td>
			<td>
				<font class="devattribute">
					<xsl:value-of select="flags/@des"/>
				</font>
			</td>
			<td>
				<font class="devattribute">
					<xsl:value-of select="revision"/>
				</font>
			</td>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>